@@ -1,6 +1,6 @@
 package Dancer::Plugin::Auth::Facebook;
 
-$Dancer::Plugin::Auth::Facebook::VERSION = '0.05';
+$Dancer::Plugin::Auth::Facebook::VERSION = '0.06';
 
 use strict;
 use warnings;
@@ -21,6 +21,7 @@ my $cb_success;
 my $cb_fail;
 my $fb_scope;
 my @scope;
+my $me_fields;
 
 register 'auth_fb_init' => sub {
   my $config = plugin_setting;
@@ -31,6 +32,7 @@ register 'auth_fb_init' => sub {
   $cb_success           = $config->{callback_success} || '/';
   $cb_fail              = $config->{callback_fail}    || '/fail';
   $fb_scope             = $config->{scope};
+  $me_fields            = $config->{fields};
 
   if (defined $fb_scope) {
     foreach my $fs (split(/\s+/, $fb_scope)) {
@@ -96,7 +98,7 @@ get '/auth/facebook/callback' => sub {
 
   my ($me, $fb_response);
   eval {
-    $fb_response = $fb->get( 'https://graph.facebook.com/v2.2/me' );
+    $fb_response = $fb->get( 'https://graph.facebook.com/v2.8/me' . ($me_fields ? "?fields=$me_fields" : '') );
     $me = $fb_response->as_hash;
   };
   if ($@ || !$me) {
@@ -154,8 +156,27 @@ authentication URL, defines automatically a callback route handler and saves the
 authenticated user to your session when done.
 
 The authenticated user information will be available as a hash reference under
-C<session('fb_user')>. Please refer to Facebook's documentation for all available
-data.
+C<session('fb_user')>. You should probably associate the C<id> field to that
+user, so you know which of your users just completed the login.
+
+The information under C<fb_user> is returned by the current user's basic
+endpoint, known on Facebook's API as C</me>. You should note that Facebook
+has a habit of changing which fields are returned on that endpoint. To force
+any particular fields, please use the C<fields> setting in your plugin
+configuration as shown below.
+
+Please refer to L<< Facebook's documentation | https://developers.facebook.com/docs/graph-api/reference/v2.8/user >>
+for all available data.
+
+=head1 FACEBOOK GRAPH API VERSION
+
+This module complies to Facebook Graph API version 2.8, the latest
+at the time of publication, B<< scheduled for deprecation on October 5th, 2018 >>.
+
+One month prior to that, Net::Facebook::Oauth2 (which this module uses to
+access Facebook's API) will trigger a warning message during your Dancer
+app's startup.
+
 
 =head1 PREREQUISITES
 
@@ -184,9 +205,10 @@ C<plugins/Auth::Facebook>:
             callback_success:   "/"
             callback_fail:      "/fail"
             scope:              "email friends"
+            fields:             "id,name,email"
 
-C<callback_success> , C<callback_fail> and C<scope> are optional and default to
-'/' , '/fail', and 'email' respectively.
+C<callback_success> , C<callback_fail>, C<scope> and C<fields> are optional
+and default to '/' , '/fail', 'email' and (empty) respectively.
 
 Note that you also need to provide your callback url, whose route handler is automatically
 created by the plugin.
@@ -254,13 +276,13 @@ L<Catalyst::Authentication::Credential::Twitter> written by Jesse Stay.
 
 =over 4
 
-=item * Prajith Ndimensionz <prajith@ndimensionz.com>
+=item * Prajith Ndimensionz <prajith@ndimensionz>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014-2015 by Prajith Ndimensionz.
+This software is copyright (c) 2014-2016 by Prajith Ndimensionz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
